@@ -19,8 +19,10 @@ namespace {
 
 using std::fprintf;
 
-enum OptionIndex { BlockName=4, Dir, Spec, PrintSpec, Title, History,
-                   Unmerged, Sort };
+enum OptionIndex {
+  BlockName=4, BlockNumber, List, Dir, Spec, PrintSpec,
+  Title, History, Unmerged, Sort
+};
 
 const option::Descriptor Usage[] = {
   { NoOp, 0, "", "", Arg::None,
@@ -32,7 +34,11 @@ const option::Descriptor Usage[] = {
   CommonUsage[Version],
   CommonUsage[Verbose],
   { BlockName, 0, "b", "block", Arg::Required,
-    "  -b NAME, --block=NAME  \tmmCIF block to convert." },
+    "  -b NAME, --block=NAME  \tmmCIF block to convert, by name." },
+  { BlockNumber, 0, "B", "", Arg::Int,
+    "  -B INDEX  \tmmCIF block to convert, by index (default: 1)." },
+  { List, 0, "l", "list", Arg::None,
+    "  -l, --list  \tdry run and list blocks in mmCIF file." },
   { Dir, 0, "d", "dir", Arg::Required,
     "  -d DIR, --dir=NAME  \tOutput directory." },
   { Spec, 0, "", "spec", Arg::Required,
@@ -65,11 +71,24 @@ gemmi::ReflnBlock& get_block_by_name(std::vector<gemmi::ReflnBlock>& rblocks,
   gemmi::fail("block not found: " + name);
 }
 
+void print_block_info(gemmi::ReflnBlock& rb, const gemmi::Mtz& mtz) {
+  std::printf("--block=%s - %.*s %zu x %zu ->",
+              rb.block.name.c_str(), (int)rb.tag_offset() - 1,
+              rb.default_loop->tags.at(0).c_str(),
+              rb.default_loop->width(), rb.default_loop->length());
+  for (const gemmi::Mtz::Column& col : mtz.columns)
+    std::printf(" %s", col.label.c_str());
+  std::putchar('\n');
+  for (const std::string& d : rb.block.find_values("_diffrn.details"))
+    std::printf("  details: %s\n", d.c_str());
+}
+
 } // anonymous namespace
 
 int GEMMI_MAIN(int argc, char **argv) {
   OptParser p(EXE_NAME);
   p.simple_parse(argc, argv, Usage);
+  p.check_exclusive_pair(BlockName, BlockNumber);
   if (p.options[PrintSpec]) {
     std::printf("# Each line in the spec contains four words:\n"
                 "# - tag (without category) from _refln or _diffrn_refln\n"
@@ -85,7 +104,8 @@ int GEMMI_MAIN(int argc, char **argv) {
       std::printf("%s\n", *line);
     return 0;
   }
-  bool convert_all = p.options[Dir];
+
+  bool convert_all = p.options[Dir] || p.options[List];
   p.require_positional_args(convert_all ? 1 : 2);
 
   gemmi::CifToMtz cif2mtz;
@@ -105,12 +125,16 @@ int GEMMI_MAIN(int argc, char **argv) {
     if (convert_all) {
       bool ok = true;
       for (gemmi::ReflnBlock& rb : rblocks) {
-        std::string path = p.options[Dir].arg;
-        path += '/';
-        path += rb.block.name;
-        path += ".mtz";
         try {
           gemmi::Mtz mtz = cif2mtz.convert_block_to_mtz(rb, std::cerr);
+          if (p.options[List]) {
+            print_block_info(rb, mtz);
+            continue;
+          }
+          std::string path = p.options[Dir].arg;
+          path += '/';
+          path += rb.block.name;
+          path += ".mtz";
           if (cif2mtz.verbose)
             fprintf(stderr, "Writing %s ...\n", path.c_str());
           mtz.write_to_file(path);
@@ -123,10 +147,18 @@ int GEMMI_MAIN(int argc, char **argv) {
         return 1;
     } else {
       const char* mtz_path = p.nonOption(1);
-      const gemmi::ReflnBlock& rb = p.options[BlockName]
-        ? get_block_by_name(rblocks, p.options[BlockName].arg)
-        : rblocks.at(0);
-      gemmi::Mtz mtz = cif2mtz.convert_block_to_mtz(rb, std::cerr);
+      const gemmi::ReflnBlock* rb;
+      if (p.options[BlockName]) {
+        rb = &get_block_by_name(rblocks, p.options[BlockName].arg);
+      } else if (p.options[BlockNumber]) {
+        int idx = std::atoi(p.options[BlockNumber].arg);
+        if (idx <= 0 || (size_t)idx > rblocks.size())
+          gemmi::fail("block index must be from 1 to ", std::to_string(rblocks.size()));
+        rb = &rblocks.at(idx - 1);
+      } else {
+        rb = &rblocks.at(0);
+      }
+      gemmi::Mtz mtz = cif2mtz.convert_block_to_mtz(*rb, std::cerr);
       if (p.options[Sort]) {
         bool reordered = mtz.sort();
         if (cif2mtz.verbose)
@@ -144,5 +176,3 @@ int GEMMI_MAIN(int argc, char **argv) {
     fprintf(stderr, "Done.\n");
   return 0;
 }
-
-// vim:sw=2:ts=2:et:path^=../include,../third_party
